<?php
/**
 * Theme functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 */

if ( ! function_exists( 'tribune_setup' ) ) :
/**
 * Theme setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 */
function tribune_setup() {
    // This theme styles the visual editor to resemble the theme style.
    add_editor_style( array( 'css/editor-style.css' ) );

    /* Default Thumbnail */
    add_image_size( 'loop', option::get( 'thumb_width' ), option::get( 'thumb_height' ), true );

    /* Featured Slider */
    add_image_size( 'featured', 650);

    /* Featured Category Widget */
    add_image_size( 'featured-cat', 256, 167, true );

    /* Footer Carousel */
    add_image_size( 'carousel', 276, 180, true );

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );

    // Register nav menus
    register_nav_menus( array(
        'secondary' => __( 'Top Menu', 'wpzoom' ),
        'primary' => __( 'Main Menu', 'wpzoom' ),
        'tertiary' => __( 'Footer Menu', 'wpzoom' )

    ) );


    /*
     * JetPack Infinite Scroll
     */
    add_theme_support( 'infinite-scroll', array(
        'container' => 'recent-posts',
        'wrapper' => false,
        'footer' => false
    ) );

    /**
     * Theme Logo
     */
    add_theme_support( 'custom-logo', array(
        'height'      => 150,
        'width'       => 650,
        'flex-height' => true,
        'flex-width'  => true
    ) );

    tribune_old_fonts();
}
endif;
add_action( 'after_setup_theme', 'tribune_setup' );



/* Add support for Custom Background
==================================== */

add_theme_support( 'custom-background' );



/* Video auto-thumbnail
==================================== */

if (is_admin()) {
    WPZOOM_Video_Thumb::init();
}



/* Custom Excerpt Length
==================================== */

function new_excerpt_length($length) {
    return (int) option::get("excerpt_length") ? (int) option::get("excerpt_length") : 50;
}
add_filter('excerpt_length', 'new_excerpt_length');




/*  Maximum width for images in posts
=========================================== */

if ( ! isset( $content_width ) ) $content_width = 810;


/* 	This will enable to insert [shortcodes] inside Text Widgets
================================================================ */

add_filter('widget_text', 'do_shortcode');



/* Display how long ago a post/comment was posted
==================================================== */

function time_ago( $type = 'post' ) {
	$d = 'comment' == $type ? 'get_comment_time' : 'get_post_time';
	return human_time_diff($d('U'), current_time('timestamp')) . " " . __('ago', 'wpzoom');
}



/* Video Embed Code Fix
==================================== */
if ( !function_exists( 'embed_fix' ) ) {
    function embed_fix($video,$width,$height) {

      $video = preg_replace("/(width\s*=\s*[\"\'])[0-9]+([\"\'])/i", "$1 ".$width." $2", $video);
      $video = preg_replace("/(height\s*=\s*[\"\'])[0-9]+([\"\'])/i", "$1 ".$height." $2", $video);
      if (strpos($video, "<embed src=" ) !== false) {
          $video = str_replace('</param><embed', '</param><param name="wmode" value="transparent"></param><embed wmode="transparent" ', $video);
      }
      else {
        if(strpos($video, "wmode=transparent") == false){

          $re1='.*?'; # Non-greedy match on filler
          $re2='((?:\\/{2}[\\w]+)(?:[\\/|\\.]?)(?:[^\\s"]*))';  # HTTP URL 1

          if ($c=preg_match_all ("/".$re1.$re2."/is", $video, $matches))
          {
            $httpurl1=$matches[1][0];
          }

          if(strpos($httpurl1, "?") == true){
            $httpurl_new = $httpurl1 . '&wmode=transparent';
          }
          else {
            $httpurl_new = $httpurl1 . '?wmode=transparent';
          }

          $search = array($httpurl1);
          $replace = array($httpurl_new);
          $video = str_replace($search, $replace, $video);

          //print($httpurl_new);
          unset($httpurl_new);

        }
      }
      return $video;
    }

}


/* Count post views
==================================== */

add_action( 'template_redirect', 'entry_views_load' );
add_action( 'wp_ajax_entry_views', 'entry_views_update_ajax' );
add_action( 'wp_ajax_nopriv_entry_views', 'entry_views_update_ajax' );

function entry_views_load() {
  global $wp_query, $entry_views_pid;

  if ( is_singular() ) {

    $post = $wp_query->get_queried_object();
        $entry_views_pid = $post->ID;
        wp_enqueue_script( 'jquery' );
        add_action( 'wp_footer', 'entry_views_load_scripts' );
  }
}

function entry_views_update( $post_id = '' ) {
  global $wp_query;

  if ( !empty( $post_id ) ) {

    $meta_key = apply_filters( 'entry_views_meta_key', 'Views' );
    $old_views = get_post_meta( $post_id, $meta_key, true );
    $new_views = absint( $old_views ) + 1;
    update_post_meta( $post_id, $meta_key, $new_views, $old_views );
  }
}


function entry_views_get( $attr = '' ) {
  global $post;

  $attr = shortcode_atts( array( 'before' => '', 'after' => '', 'post_id' => $post->ID ), $attr );
  $meta_key = apply_filters( 'entry_views_meta_key', 'Views' );
  $views = intval( get_post_meta( $attr['post_id'], $meta_key, true ) );
  return $attr['before'] . number_format_i18n( $views ) . $attr['after'];
}


function entry_views_update_ajax() {

  check_ajax_referer( 'entry_views_ajax' );

  if ( isset( $_POST['post_id'] ) )
    $post_id = absint( $_POST['post_id'] );

  if ( !empty( $post_id ) )
    entry_views_update( $post_id );
}


function entry_views_load_scripts() {
  global $entry_views_pid;

  $nonce = wp_create_nonce( 'entry_views_ajax' );

  echo '<script type="text/javascript">/* <![CDATA[ */ jQuery(document).ready( function() { jQuery.post( "' . admin_url( 'admin-ajax.php' ) . '", { action : "entry_views", _ajax_nonce : "' . $nonce . '", post_id : ' . $entry_views_pid . ' } ); } ); /* ]]> */</script>' . "\n";
}




if ( ! function_exists( 'tribune_remove_hentry' ) ) :
/**
 * Remove hentry class from pages, because they don't contain date, nor authors,
 * therefore this entities are not hentries.
 */
function tribune_remove_hentry( $classes ) {
    $classes = array_diff( $classes, array( 'hentry' ) );

    return $classes;
}
endif;

add_filter( 'post_class', 'tribune_remove_hentry' );


/* Custom Archives titles.
=================================== */

if ( ! function_exists( 'tribune_get_the_archive_title' ) ) :

function tribune_get_the_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    }

    return $title;
}
endif;
add_filter( 'get_the_archive_title', 'tribune_get_the_archive_title' );



if ( ! function_exists( 'tribune_alter_main_query' ) ) :
/**
 * Alter main WordPress Query to exclude specific categories
 * and posts from featured slider if this is configured via Theme Options.
 *
 * @param $query WP_Query
 */
function tribune_alter_main_query( $query ) {
    // until this is fixed https://core.trac.wordpress.org/ticket/27015
    $is_front = false;

    if ( get_option( 'page_on_front' ) == 0 ) {
        $is_front = is_front_page();
    } else {
        $is_front = $query->get( 'page_id' ) == get_option( 'page_on_front' );
    }

    if ( $query->is_main_query() && $is_front ) {
        if ( option::is_on( 'hide_featured' ) ) {
            $featured_posts = new WP_Query( array(
                'post__not_in'   => get_option( 'sticky_posts' ),
                'posts_per_page' => option::get( 'featured_number' ),
                'meta_key'       => 'wpzoom_is_featured',
                'meta_value'     => 1
            ) );

            $postIDs = array();
            while ( $featured_posts->have_posts() ) {
                $featured_posts->the_post();
                $postIDs[] = get_the_ID();
            }

            wp_reset_postdata();

            $query->set( 'post__not_in', $postIDs );
        }

        if ( count( option::get( 'recent_part_exclude' ) ) ) {
            $query->set( 'cat', '-' . implode( ',-', (array) option::get('recent_part_exclude') ) );
        }
    }
}
endif;
add_action( 'pre_get_posts', 'tribune_alter_main_query' );


/* Enqueue scripts and styles for the front end.
=========================================== */

function tribune_scripts() {

    if ( '' !== $google_request = tribune_get_google_font_uri() ) {
        wp_enqueue_style( 'tribune-google-fonts', $google_request, WPZOOM::$themeVersion );
    }

    // Load our main stylesheet.
    wp_enqueue_style( 'tribune-style', get_stylesheet_uri() );

    wp_enqueue_style( 'media-queries', get_template_directory_uri() . '/css/media-queries.css', array(), WPZOOM::$themeVersion );


    wp_enqueue_style( 'tribune-google-font-default', '//fonts.googleapis.com/css?family=Montserrat:400,700|Playfair+Display:400,700|Roboto+Condensed:400,700|Merriweather:400,700,900,400italic,700italic,900italic&subset=latin,greek,cyrillic' );

    wp_enqueue_style( 'dashicons' );

    wp_enqueue_script( 'mmenu', get_template_directory_uri() . '/js/jquery.mmenu.min.all.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

    wp_enqueue_script( 'flickity', get_template_directory_uri() . '/js/flickity.pkgd.min.js', array(), WPZOOM::$themeVersion, true );

    wp_enqueue_script( 'carouFredSel', get_template_directory_uri() . '/js/jquery.carouFredSel-6.2.1-packed.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

    wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/js/flexslider.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

    wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

    wp_enqueue_script( 'superfish', get_template_directory_uri() . '/js/superfish.min.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

    wp_enqueue_script( 'tabber-tabs', get_template_directory_uri() . '/js/tabs.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

    wp_enqueue_script( 'search_button', get_template_directory_uri() . '/js/search_button.js', array(), WPZOOM::$themeVersion, true );

    $themeJsOptions = option::getJsOptions();

    wp_enqueue_script( 'tribune-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), WPZOOM::$themeVersion, true );
    wp_localize_script( 'tribune-script', 'zoomOptions', $themeJsOptions );

}

add_action( 'wp_enqueue_scripts', 'tribune_scripts' );

if ( ! function_exists( 'tribune_custom_logo' ) ) :
    /**
     * Show custom logo or blog title and description.
     *
     */
    function tribune_custom_logo() {
        //In future must remove it is for backward compatibility.
        if ( get_theme_mod( 'logo' ) ) {
            set_theme_mod( 'custom_logo', zoom_get_attachment_id_from_url( get_theme_mod( 'logo' ) ) );
            remove_theme_mod( 'logo' );
        }

        has_custom_logo() ? the_zoom_custom_logo() : printf( '<h1><a href="%s" title="%s">%s</a></h1>', home_url(), get_bloginfo( 'description' ), get_bloginfo( 'name' ) );
    }
endif;

if ( ! function_exists( 'tribune_footer_custom_logo' ) ) :
    /**
     * Show custom logo or blog title and description.
     *
     */
    function tribune_footer_custom_logo() {
        $show_logo = (bool) get_theme_mod('footer-show-image-logo');
        has_custom_logo() && $show_logo ? the_zoom_custom_logo() : printf( '<h2><a href="%s" title="%s">%s</a></h2>', home_url(), get_bloginfo( 'description' ), get_bloginfo( 'name' ) );
    }
endif;

if( ! function_exists( 'tribune_get_google_font_uri' ) ) :
    /**
     * Build the HTTP request URL for Google Fonts.
     *
     * @return string    The URL for including Google Fonts.
     */
    function tribune_get_google_font_uri() {
        // Grab the font choices
        $font_keys = zoom_customizer_get_font_familiy_ids(tribune_customizer_data());

        $fonts = array();
        foreach ( $font_keys as $key => $default ) {
            $fonts[] = get_theme_mod( $key, $default );
        }

        // De-dupe the fonts
        $fonts         = array_unique( $fonts );
        $allowed_fonts = zoom_customizer_get_google_fonts();
        $family        = array();

        // Validate each font and convert to URL format
        foreach ( $fonts as $font ) {
            $font = trim( $font );

            // Verify that the font exists
            if ( array_key_exists( $font, $allowed_fonts ) ) {
                // Build the family name and variant string (e.g., "Open+Sans:regular,italic,700")
                $family[] = urlencode( $font . ':' . join( ',', zoom_customizer_choose_google_font_variants( $font, $allowed_fonts[ $font ]['variants'] ) ) );
            }
        }

        // Convert from array to string
        if ( empty( $family ) ) {
            return '';
        } else {
            $request = '//fonts.googleapis.com/css?family=' . implode( '|', $family );
        }

        // Load the font subset
        $subset = get_theme_mod( 'font-subset', false );

        if ( 'all' === $subset ) {

            $subsets_available = zoom_customizer_get_google_font_subsets();

            // Remove the all set
            unset( $subsets_available['all'] );

            // Build the array
            $subsets = array_keys( $subsets_available );
        } else {
            $subsets = array(
                'latin',
                $subset,
            );
        }

        // Append the subset string
        if ( ! empty( $subsets ) ) {
            $request .= urlencode( '&subset=' . join( ',', $subsets ) );
        }

        /**
         * Filter the Google Fonts URL.
         *
         * @since 1.2.3.
         *
         * @param string    $url    The URL to retrieve the Google Fonts.
         */
        return apply_filters( 'tribune_get_google_font_uri', esc_url( $request ) );
    }
endif;
if ( ! function_exists( 'tribune_old_fonts' ) ) :
    function tribune_old_fonts() {

        if ( get_theme_mod( 'font-family-site-body' ) ) {
            set_theme_mod( 'body-font-family', get_theme_mod( 'font-family-site-body' ) );
            remove_theme_mod( 'font-family-site-body' );
        }

        if ( get_theme_mod( 'font-family-site-title' ) ) {
            set_theme_mod( 'title-font-family', get_theme_mod( 'font-family-site-title' ) );
            remove_theme_mod( 'font-family-site-title' );
        }

        if ( get_theme_mod( 'font-family-site-tagline' ) ) {
            set_theme_mod( 'description-font-family', get_theme_mod( 'font-family-site-tagline' ) );
            remove_theme_mod( 'font-family-site-tagline' );
        }

        if ( get_theme_mod( 'font-family-nav-top' ) ) {
            set_theme_mod( 'topmenu-font-family', get_theme_mod( 'font-family-nav-top' ) );
            remove_theme_mod( 'font-family-nav-top' );
        }

        if ( get_theme_mod( 'font-family-nav' ) ) {
            set_theme_mod( 'mainmenu-font-family', get_theme_mod( 'font-family-nav' ) );
            remove_theme_mod( 'font-family-nav' );
        }

        if ( get_theme_mod( 'font-family-slider-title' ) ) {
            set_theme_mod( 'slider-title-font-family', get_theme_mod( 'font-family-slider-title' ) );
            remove_theme_mod( 'font-family-slider-title' );
        }

        if ( get_theme_mod( 'font-family-widgets' ) ) {
            set_theme_mod( 'widget-title-font-family', get_theme_mod( 'font-family-widgets' ) );
            remove_theme_mod( 'font-family-widgets' );
        }

        if ( get_theme_mod( 'font-family-post-title' ) ) {
            set_theme_mod( 'blog-title-font-family', get_theme_mod( 'font-family-post-title' ) );
            remove_theme_mod( 'font-family-post-title' );
        }

        if ( get_theme_mod( 'font-family-single-post-title' ) ) {
            set_theme_mod( 'post-title-font-family', get_theme_mod( 'font-family-single-post-title' ) );
            remove_theme_mod( 'font-family-single-post-title' );
        }

        if ( get_theme_mod( 'font-family-page-title' ) ) {
            set_theme_mod( 'page-title-font-family', get_theme_mod( 'font-family-page-title' ) );
            remove_theme_mod( 'font-family-page-title' );
        }

    }
endif;
