<?php

/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * This function reads in the options from theme mods and determines whether a CSS rule is needed to implement an
 * option. CSS is only written for choices that are non-default in order to avoid adding unnecessary CSS. All options
 * are also filterable allowing for more precise control via a child theme or plugin.
 *
 * Note that all CSS for options is present in this function except for the CSS for fonts and the logo, which require
 * a lot more code to implement.
 *
 * @return void
 */
function tribune_css_add_rules() {
    /**
     * Colors section
     */
    tribune_css_add_simple_color_rule( 'color-body-text', 'body', 'color' );

    tribune_css_add_simple_color_rule( 'color-logo', '.navbar-brand a, .navbar-brand a:hover', 'color' );
    tribune_css_add_simple_color_rule( 'color-link', 'a, .widget .feature-posts-list li a, .carousel-slider .item .entry-title a', 'color' );
    tribune_css_add_simple_color_rule( 'color-link-hover', 'a:hover, .widget .feature-posts-list li a:hover, .carousel-slider .item .entry-title a:hover', 'color' );

    // Top Menu
    tribune_css_add_simple_color_rule( 'color-top-menu-link', '.top-navbar a', 'color' );
    tribune_css_add_simple_color_rule( 'color-top-menu-link-hover', '.top-navbar a:hover', 'color' );
    tribune_css_add_simple_color_rule( 'color-top-menu-link-current', '.navbar-nav .current-menu-item > a, .navbar-nav .current_page_item > a, .navbar-nav .current-menu-parent > a', 'color' );

    // Main Menu
    tribune_css_add_simple_color_rule( 'color-menu-background', '.main-navbar', 'background' );
    tribune_css_add_simple_color_rule( 'color-menu-link', '.main-navbar .navbar-nav a', 'color' );
    tribune_css_add_simple_color_rule( 'color-menu-link-hover', '.main-navbar .navbar-nav a:hover', 'color' );
    tribune_css_add_simple_color_rule( 'color-menu-link-current', '.main-navbar .current-menu-item > a, .main-navbar .current_page_item > a, .main-navbar .current-menu-parent > a, .main-navbar .current_page_parent > a', 'color' );

    // Breaking News Bar
    tribune_css_add_simple_color_rule( 'breaking-background', '#news-ticker', 'background' );
    tribune_css_add_simple_color_rule( 'breaking-border', '#news-ticker', 'border-color' );
    tribune_css_add_simple_color_rule( 'breaking-date', '#news-ticker dt', 'background' );
    tribune_css_add_simple_color_rule( 'breaking-date-text', '#news-ticker dt', 'color' );
    tribune_css_add_simple_color_rule( 'breaking-link', '#news-ticker dd a', 'color' );
    tribune_css_add_simple_color_rule( 'breaking-link-hover', '#news-ticker dd a:hover', 'color' );

    // Slider
    tribune_css_add_simple_color_rule( 'slider-navigator', '.flex-control-nav', 'background' );
    tribune_css_add_simple_color_rule( 'slider-post-link', '#slider #slidemain .slide_content h2 a', 'color' );
    tribune_css_add_simple_color_rule( 'slider-post-link-hover', '#slider #slidemain .slide_content h2 a:hover', 'color' );

    // Post
    tribune_css_add_simple_color_rule( 'color-post-title', '#main .homepage-widgets .homecat ul li h3 a, .recent-posts .entry-title a, h1.entry-title', 'color' );
    tribune_css_add_simple_color_rule( 'color-post-title-hover', '#main .homepage-widgets .homecat ul li h3 a:hover, .recent-posts .entry-title a:hover', 'color' );

    tribune_css_add_simple_color_rule( 'color-post-category', '.cat-links a', 'color' );
    tribune_css_add_simple_color_rule( 'color-post-category-hover', '.cat-links a:hover', 'color' );
    tribune_css_add_simple_color_rule( 'color-post-meta', '.entry-meta, .post-meta .entry-date, .post-meta', 'color' );
    tribune_css_add_simple_color_rule( 'color-post-meta-link', '.entry-meta a', 'color' );
    tribune_css_add_simple_color_rule( 'color-post-meta-link-hover', '.entry-meta a:hover', 'color' );

    // Widgets
    tribune_css_add_simple_color_rule( 'color-widget-title', '.widget h3.title, .widget .tabbernav .tabberactive a, .widget .tabbernav li a:hover', 'color' );

    // Footer
    tribune_css_add_simple_color_rule( 'color-footer-background', '#footer', 'background' );
    tribune_css_add_simple_color_rule( 'color-footer-text', '#footer', 'color' );
    tribune_css_add_simple_color_rule( 'color-footer-link', '#footer a', 'color' );
    tribune_css_add_simple_color_rule( 'color-footer-link-hover', '#footer a:hover', 'color' );

    // Buttons
    tribune_css_add_simple_color_rule( 'color-button-background', 'button, input[type=button], input[type=reset], input[type=submit]', 'background' );
    tribune_css_add_simple_color_rule( 'color-button-color', 'button, input[type=button], input[type=reset], input[type=submit]', 'color' );
    tribune_css_add_simple_color_rule( 'color-button-background-hover', 'button:hover, input[type=button]:hover, input[type=reset]:hover, input[type=submit]:hover', 'background' );
    tribune_css_add_simple_color_rule( 'color-button-color-hover', 'button:hover, input[type=button]:hover, input[type=reset]:hover, input[type=submit]:hover', 'color' );


}

add_action( 'tribune_css', 'tribune_css_add_rules' );

function tribune_css_add_simple_color_rule( $setting_id, $selectors, $declarations ) {
    $value = maybe_hash_hex_color( get_theme_mod( $setting_id, tribune_get_default( $setting_id ) ) );

    if ( $value === tribune_get_default( $setting_id ) ) {
        return;
    }

    if ( strtolower( $value ) === strtolower( tribune_get_default( $setting_id ) ) ) {
        return;
    }

    if ( is_string( $selectors ) ) {
        $selectors = array( $selectors );
    }

    if ( is_string( $declarations ) ) {
        $declarations = array(
            $declarations => $value
        );
    }

    tribune_get_css()->add( array(
        'selectors'    => $selectors,
        'declarations' => $declarations
    ) );
}
